/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2017 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy17nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy17nid ;

DATA library.&dataset ;
INFILE datafile LRECL=320;
INPUT
   USSCIDN  1-7             STMIN851  8-11           STMAX851  12-16       
   FILED  17                WITHDRWN  18             RELIEF  19            
   CTRELIEF  20             CRMHT851  21             INDTDATE DATE11.      
   FILEDATE DATE11.         PROFFN1  44-46           PROFFN2  47-49        
   PROFFN3  50-52           PROFFN4  53-55           PROFFN5  56-58        
   PROFFN6  59-61           PROFFN7  62-64           PROFFN8  65-67        
   PROFFN9  68-70           PROFFN10  71-73          PROFFN11  74-76       
   PROFFN12  77-79          PROFFN13  80-82          PROFFN14  83-85       
   PRSENT1  86-89           PRSENT2  90-93           PRSENT3  94-97        
   PRSENT4  98-101          PRSENT5  102-105         PRSENT6  106-109      
   PRSENT7  110-113         PRSENT8  114-117         PRSENT9  118-120      
   PRSENT10  121-123        PRSENT11  124-126        PRSENT12  127-130     
   PRSENT13  131-132        PRSENT14  133-136        PRSNDT1 DATE11.       
   PRSNDT2 DATE11.          PRSNDT3 DATE11.          PRSNDT4 DATE11.       
   PRSNDT5 DATE11.          PRSNDT6 DATE11.          PRSNDT7 DATE11.       
   PRSNDT8 DATE11.          PRSNDT9 DATE11.          PRSNDT10 DATE11.      
   PRSNDT11 DATE11.         PRSNDT12 DATE11.         PRSNDT13 DATE11.      
   PRSNDT14 DATE11.         OFFENNUM  291-292        PRCHPT1  293          
   PRCHPT2  294             PRCHPT3  295             PRCHPT4  296          
   PRCHPT5  297             PRCHPT6  298             PRCHPT7  299          
   PRCHPT8  300             PRCHPT9  301             PRCHPT10  302         
   PRCHPT11  303            PRCHPT12  304            PRCHPT13  305         
   PRCHPT14  306            PRFELN1  307             PRFELN2  308          
   PRFELN3  309             PRFELN4  310             PRFELN5  311          
   PRFELN6  312             PRFELN7  313             PRFELN8  314          
   PRFELN9  315             PRFELN10  316            PRFELN11  317         
   PRFELN12  318            PRFELN13  319            PRFELN14  320         
 ;                       

FORMAT
   INDTDATE DATE9.          FILEDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.        ;
                      

LENGTH
   USSCIDN 6                STMIN851 4               STMAX851 4            
   FILED 3                  WITHDRWN 3               RELIEF 3              
   CTRELIEF 3               CRMHT851 3               PROFFN1 4             
   PROFFN2 4                PROFFN3 4                PROFFN4 4             
   PROFFN5 4                PROFFN6 4                PROFFN7 4             
   PROFFN8 4                PROFFN9 4                PROFFN10 4            
   PROFFN11 4               PROFFN12 4               PROFFN13 4            
   PROFFN14 4               PRSENT1 4                PRSENT2 4             
   PRSENT3 4                PRSENT4 4                PRSENT5 4             
   PRSENT6 4                PRSENT7 4                PRSENT8 4             
   PRSENT9 4                PRSENT10 4               PRSENT11 4            
   PRSENT12 4               PRSENT13 3               PRSENT14 4            
   OFFENNUM 3               PRCHPT1 3                PRCHPT2 3             
   PRCHPT3 3                PRCHPT4 3                PRCHPT5 3             
   PRCHPT6 3                PRCHPT7 3                PRCHPT8 3             
   PRCHPT9 3                PRCHPT10 3               PRCHPT11 3            
   PRCHPT12 3               PRCHPT13 3               PRCHPT14 3            
   PRFELN1 3                PRFELN2 3                PRFELN3 3             
   PRFELN4 3                PRFELN5 3                PRFELN6 3             
   PRFELN7 3                PRFELN8 3                PRFELN9 3             
   PRFELN10 3               PRFELN11 3               PRFELN12 3            
   PRFELN13 3               PRFELN14 3 ;

        

RUN ;
